builder property
builder- required - builder is public in order to access WebViewController. This allows devs to wrap child with some widgets that provide features like reload, refresh go back etc. See WebViewController documentation
Implementation
final Function(WebViewController? controller, Widget child) builder;